homology.PersDiag
=================

.. currentmodule:: homology

.. autoclass:: PersDiag

   

      .. autosummary::
         :toctree:
      
         PersDiag.bin
         PersDiag.bin_bot
         PersDiag.bin_diag
         PersDiag.bin_len
         PersDiag.bin_top
         PersDiag.clip
         PersDiag.grab
         PersDiag.plot
         PersDiag.syzygy
         PersDiag.transform



   

